Learn R Programming

weaana (version 0.3.0)

[,WeaAna-method: Getter to access the weather data at a specific position.

Description

Getter to access the weather data at a specific position.

Usage

# S4 method for WeaAna
[(x, i, j, drop)

Value

A WeaAnaSite object at the position i.

Arguments

x

A WeaAna object.

i

the specific position which will access.

j

None use parameter.

drop

None use parameter.

Examples

Run this code
library(weaana)
data( "WeatherRecordsDemo" ) 
records[1]
records[1:2]
records[2:2]

Run the code above in your browser using DataLab