Learn R Programming

weaana (version 0.3.0)

add_rh: Add relative humidity to APSIM weather data

Description

This function adds relative humidity data to APSIM weather records based on a standard weather file.

Usage

add_rh(apsim, standard, output = NULL, overwrite = FALSE)

Value

A data frame containing the new weather records with relative humidity added.

Arguments

apsim

A character string specifying the path to the APSIM weather file.

standard

A character string specifying the path to the standard weather file containing relative humidity data.

output

A character string specifying the path to save the modified APSIM weather file with relative humidity data. If NULL, the function will not save the file.

overwrite

A logical value indicating whether to overwrite the output file if it already exists. Default is FALSE.