This function adds relative humidity data to APSIM weather records based on a standard weather file.
add_rh(apsim, standard, output = NULL, overwrite = FALSE)A data frame containing the new weather records with relative humidity added.
A character string specifying the path to the APSIM weather file.
A character string specifying the path to the standard weather file containing relative humidity data.
A character string specifying the path to save the modified APSIM weather file with relative humidity data. If NULL, the function will not save the file.
A logical value indicating whether to overwrite the output file if it already exists. Default is FALSE.